@@ -45,10 +45,6 @@ UkuiMenuInterface::~UkuiMenuInterface()
 //文件递归查询
 void UkuiMenuInterface::recursiveSearchFile(const QString& _filePath)
 {
-    GError** error=nullptr;
-    GKeyFileFlags flags=G_KEY_FILE_NONE;
-    GKeyFile* keyfile=g_key_file_new ();
-
     QDir dir(_filePath);
     if (!dir.exists()) {
         return;
@@ -79,6 +75,8 @@ void UkuiMenuInterface::recursiveSearchFile(const QString& _filePath)
                 i++;
                 continue;
             }
+            keyfile=g_key_file_new();
+
             QByteArray fpbyte=filePathStr.toLocal8Bit();
             char* filepath=fpbyte.data();
             g_key_file_load_from_file(keyfile,filepath,flags,error);
@@ -88,6 +86,7 @@ void UkuiMenuInterface::recursiveSearchFile(const QString& _filePath)
                 QString str=QString::fromLocal8Bit(ret_1);
                 if(str.contains("true"))
                 {
+                    g_key_file_free(keyfile);
                     i++;
                     continue;
                 }
@@ -98,6 +97,7 @@ void UkuiMenuInterface::recursiveSearchFile(const QString& _filePath)
                 QString str=QString::fromLocal8Bit(ret_2);
                 if(str.contains("UKUI"))
                 {
+                    g_key_file_free(keyfile);
                     i++;
                     continue;
                 }
@@ -110,6 +110,7 @@ void UkuiMenuInterface::recursiveSearchFile(const QString& _filePath)
                 QString str=QString::fromLocal8Bit(ret);
                 if(str.contains("LXQt") || str.contains("KDE"))
                 {
+                    g_key_file_free(keyfile);
                     i++;
                     continue;
                 }
@@ -123,6 +124,7 @@ void UkuiMenuInterface::recursiveSearchFile(const QString& _filePath)
                 char* nameEn=g_key_file_get_string(keyfile,"Desktop Entry","Name", nullptr);
                 if(QString::fromLocal8Bit(nameCh).isEmpty() && QString::fromLocal8Bit(nameEn).isEmpty())
                 {
+                    g_key_file_free(keyfile);
                     i++;
                     continue;
                 }
@@ -131,19 +133,18 @@ void UkuiMenuInterface::recursiveSearchFile(const QString& _filePath)
                 char* name=g_key_file_get_string(keyfile,"Desktop Entry","Name", nullptr);
                 if(QString::fromLocal8Bit(name).isEmpty())
                 {
+                    g_key_file_free(keyfile);
                     i++;
                     continue;
                 }
             }
 
+            g_key_file_free(keyfile);
             filePathList.append(filePathStr);
         }
         i++;
 
     } while(i < list.size());
-
-    g_key_file_free(keyfile);
-
 }
 
 //获取系统deskyop文件路径
